==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/user/messages/eu/base.php <==
<?php
return array (
  '<strong>Followers</strong>' => '',
  '<strong>Following</strong>' => '',
  '<strong>Group</strong> members - {group}' => '',
  '<strong>Member</strong> in these spaces' => '',
  '<strong>Member</strong> of these Spaces' => '',
  '<strong>People</strong>' => '',
  '<strong>User</strong> tags' => '',
  'All' => 'Denak',
  'Any' => '',
  'Auth Mode' => '',
  'Basic Settings' => '',
  'Change Email' => '',
  'Change Password' => '',
  'Change Username' => '',
  'Confirm new password' => '',
  'Connect account' => '',
  'Connected Accounts' => '',
  'Connected accounts' => '',
  'Created at' => '',
  'Created by' => '',
  'Current password' => '',
  'Currently in use' => '',
  'Default Group' => '',
  'Default Space' => '',
  'Delete' => 'Ezabatu',
  'Delete Account' => '',
  'Description' => '',
  'Did you forget your password?' => '',
  'Disconnect account' => '',
  'Email' => '',
  'Enable Notifications' => '',
  'Find people by their profile data or user tags' => '',
  'Follow' => '',
  'Followers' => '',
  'Following' => '',
  'Following (User)' => '',
  'Force password change upon first login' => '',
  'Force password change upon next login' => '',
  'Friends' => 'Lagunak',
  'Here you can connect to external service provider for using external services like a single sign on authentication.' => '',
  'If this wasn\'t you, you can disregard this message.' => '',
  'Invite by email' => 'Posta elektronikoaren bidez gonbidatu',
  'Invite by link' => 'Estekaren bidez gonbidatu',
  'Invite new people' => '',
  'Invited by' => 'Gonbidatua',
  'It looks like you clicked on an invalid password reset link. Please try again.' => '',
  'Language' => 'Hizkuntza',
  'Last Login' => '',
  'Manager' => '',
  'Missing E-Mail Attribute from AuthClient.' => '',
  'Missing ID AuthClient Attribute from AuthClient.' => '',
  'Modules' => 'Moduluak',
  'Name' => '',
  'New password' => '',
  'No results found!' => '',
  'No users found.' => '',
  'Notifications' => 'Jakinarazpenak',
  'Offline' => '',
  'Online' => '',
  'Password' => '',
  'Password changed' => '',
  'Password needs to be at least {chars} characters long.' => '',
  'Password recovery' => '',
  'Pending Requests' => '',
  'People' => 'Jendea',
  'Permission' => '',
  'Profile' => '',
  'Profile posts only' => '',
  'Register now and participate!' => '',
  'Search...' => 'Bilatu...',
  'Security' => '',
  'Settings' => 'Ezarpenak',
  'Show At Registration' => '',
  'Show all content' => '',
  'Sign in' => '',
  'Sign in / up' => '',
  'Sign up' => 'Izena eman',
  'Sign up now' => '',
  'Sort order' => '',
  'Source' => '',
  'Status' => '',
  'Tags' => '',
  'The secure link has been copied in your clipboard!' => '',
  'Try other keywords or remove filters.' => '',
  'Unknown user status!' => '',
  'Unsuccessful login attempts since last login: {failedLoginAttemptsCount}' => '',
  'Updated at' => '',
  'Updated by' => '',
  'User' => '',
  'User Group' => '',
  'User has been invited.' => '',
  'Username' => '',
  'Username contains invalid characters.' => '',
  'Visibility' => '',
  'Visible' => '',
  'Welcome to %appName%' => '',
  'Welcome to %appName%. Please click on the button below to proceed with your registration.' => '',
  'Whenever a user follows another user.' => '',
  'You got an invite' => '',
  'You tried registering an account with %appName%, but already have an account associated with this email address.' => '',
  'You\'re not registered.' => '',
  'You\'ve been invited to join {space} on {appName}' => '',
  'Your account is disabled!' => '',
  'Your account is not approved yet!' => '',
  'Your are already logged in! - Logout first!' => '',
  'Your new password must not be equal your current password!' => '',
  'invited you to join {name}.' => '',
  'invited you to join {space} on {name}.' => '',
  'or' => '',
);

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/modules/user/messages/eu/base.php <==
<?php
return array (
  '<strong>Followers</strong>' => '',
  '<strong>Following</strong>' => '',
  '<strong>Member</strong> in these spaces' => '',
  '<strong>Member</strong> of these Spaces' => '',
  '<strong>People</strong>' => '',
  '<strong>User</strong> tags' => '',
  'Advanced Profile Search' => '',
  'All' => 'Denak',
  'Allow users to mention you' => '',
  'Allows access to your about page with personal information' => '',
  'Any' => '',
  'Auth Mode' => '',
  'Basic Settings' => '',
  'Block user' => '',
  'Change Email' => '',
  'Change Password' => '',
  'Change Username' => '',
  'Confirm new password' => '',
  'Connect account' => '',
  'Connected Accounts' => '',
  'Connected accounts' => '',
  'Created at' => '',
  'Created by' => '',
  'Current password' => '',
  'Currently in use' => '',
  'Default Group' => '',
  'Default Space' => '',
  'Delete' => 'Ezabatu',
  'Delete Account' => '',
  'Description' => 'Deskribapena',
  'Did you forget your password?' => '',
  'Disconnect account' => '',
  'Edit' => 'Editatu',
  'Email' => '',
  'Enable Notifications' => '',
  'Find people by their profile data or user tags' => '',
  'Follow' => '',
  'Followers' => '',
  'Following' => '',
  'Following (User)' => '',
  'Force password change upon first login' => '',
  'Force password change upon next login' => '',
  'Friends' => 'Lagunak',
  'Group Manager(s)' => '',
  'Here you can connect to external service provider for using external services like a single sign on authentication.' => '',
  'If this wasn\'t you, you can disregard this message.' => '',
  'Invite by email' => 'Posta elektronikoaren bidez gonbidatu',
  'Invite by link' => 'Estekaren bidez gonbidatu',
  'Invite new people' => 'Gonbidatu jende berria',
  'Invited by' => 'Gonbidatua',
  'It looks like you clicked on an invalid password reset link. Please try again.' => '',
  'Language' => 'Hizkuntza',
  'Last Login' => '',
  'Mentioning' => '',
  'Missing E-Mail Attribute from AuthClient.' => '',
  'Missing ID AuthClient Attribute from AuthClient.' => '',
  'Modules' => 'Moduluak',
  'My Account' => '',
  'Name' => '',
  'New password' => '',
  'No results found!' => '',
  'No users found.' => '',
  'Notifications' => 'Jakinarazpenak',
  'Offline' => '',
  'Online' => '',
  'Password' => 'Pasahitza',
  'Password changed' => '',
  'Password needs to be at least {chars} characters long.' => '',
  'Password recovery' => '',
  'Pending Requests' => '',
  'People' => 'Jendea',
  'Permission' => '',
  'Profile' => '',
  'Profile posts only' => '',
  'Register now and participate!' => '',
  'Search...' => 'Bilatu...',
  'Security' => '',
  'Settings' => 'Ezarpenak',
  'Show At Registration' => '',
  'Show all content' => '',
  'Sign in' => '',
  'Sign in / up' => '',
  'Sign up' => 'Izena eman',
  'Sign up now' => '',
  'Sort order' => '',
  'Source' => '',
  'Status' => '',
  'Tags' => '',
  'The Group Manager can approve pending registrations of this group.' => '',
  'The secure link has been copied in your clipboard!' => '',
  'The user has been blocked for you.' => '',
  'The user has been unblocked for you.' => '',
  'Try other keywords or remove filters.' => '',
  'Unblock user' => '',
  'Unknown user status!' => '',
  'Unsuccessful login attempts since last login: {failedLoginAttemptsCount}' => '',
  'Updated at' => '',
  'Updated by' => '',
  'User' => 'Erabiltzailea',
  'User Group' => '',
  'User has been invited.' => '',
  'Username' => 'Erabiltzaile izena',
  'Username contains invalid characters.' => '',
  'View your about page' => '',
  'Visibility' => '',
  'Visible' => '',
  'Welcome to %appName%' => '',
  'Welcome to %appName%. Please click on the button below to proceed with your registration.' => '',
  'Whenever a user follows another user.' => '',
  'You got an invite' => '',
  'You tried registering an account with %appName%, but already have an account associated with this email address.' => '',
  'You\'re not registered.' => '',
  'You\'ve been invited to join {space} on {appName}' => '',
  'Your account is disabled!' => '',
  'Your account is not approved yet!' => '',
  'Your are already logged in! - Logout first!' => '',
  'Your new password must not be equal your current password!' => '',
  'invited you to join {name}.' => '',
  'invited you to join {space} on {name}.' => '',
  'or' => '',
);
